@@ -118,6 +118,65 @@
     ((("_"). (""))())
     ((("Y"). (""))())
     ((("\\"). (""))())
+    ((("yen"). (""))())
+
+    ((("kana-a"). (""))())
+    ((("kana-i"). (""))())
+    ((("kana-u"). (""))())
+    ((("kana-e"). (""))())
+    ((("kana-o"). (""))())
+    ((("kana-ya"). (""))())
+    ((("kana-yu"). (""))())
+    ((("kana-yo"). (""))())
+    ((("kana-WO"). (""))())
+    ((("kana-tsu"). (""))())
+    ((("kana-N"). (""))())
+    ((("kana-A"). (""))())
+    ((("kana-I"). (""))())
+    ((("kana-U"). (""))())
+    ((("kana-E"). (""))())
+    ((("kana-O"). (""))())
+    ((("kana-KA"). (""))())
+    ((("kana-KI"). (""))())
+    ((("kana-KU"). (""))())
+    ((("kana-KE"). (""))())
+    ((("kana-KO"). (""))())
+    ((("kana-SA"). (""))())
+    ((("kana-SHI"). (""))())
+    ((("kana-SU"). (""))())
+    ((("kana-SE"). (""))())
+    ((("kana-SO"). (""))())
+    ((("kana-TA"). (""))())
+    ((("kana-CHI"). (""))())
+    ((("kana-TSU"). (""))())
+    ((("kana-TE"). (""))())
+    ((("kana-TO"). (""))())
+    ((("kana-NA"). (""))())
+    ((("kana-NI"). (""))())
+    ((("kana-NU"). (""))())
+    ((("kana-NE"). (""))())
+    ((("kana-NO"). (""))())
+    ((("kana-HA"). (""))())
+    ((("kana-HI"). (""))())
+    ((("kana-FU"). (""))())
+    ((("kana-HE"). (""))())
+    ((("kana-HO"). (""))())
+    ((("kana-MA"). (""))())
+    ((("kana-MI"). (""))())
+    ((("kana-MU"). (""))())
+    ((("kana-ME"). (""))())
+    ((("kana-MO"). (""))())
+    ((("kana-YA"). (""))())
+    ((("kana-YU"). (""))())
+    ((("kana-YO"). (""))())
+    ((("kana-RA"). (""))())
+    ((("kana-RI"). (""))())
+    ((("kana-RU"). (""))())
+    ((("kana-RE"). (""))())
+    ((("kana-RO"). (""))())
+    ((("kana-WA"). (""))())
+    ((("kana-prolonged-sound"). (""))())
+
     ((("" "@"). ())("" ""))
     ((("" "@"). ())("" ""))
     ((("" "@"). ())("" ""))
@@ -163,6 +222,33 @@
     ((("" "`"). ())("" ""))
     ((("" "`"). ())("" ""))
     ((("" "`"). ())("" ""))
+
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-voiced-sound"). ())("" ""))
+    ((("" "kana-semivoiced-sound"). ())("" ""))
+    ((("" "kana-semivoiced-sound"). ())("" ""))
+    ((("" "kana-semivoiced-sound"). ())("" ""))
+    ((("" "kana-semivoiced-sound"). ())("" ""))
+    ((("" "kana-semivoiced-sound"). ())("" ""))
+
     (((">"). (""))())
     ((("<"). (""))())
     ((("?"). (""))())
@@ -172,6 +258,14 @@
     ((("}"). (""))())
     ((("`"). (""))())
 
+    ((("kana-fullstop"). (""))())
+    ((("kana-comma"). (""))())
+    ((("kana-conjunctive"). (""))())
+    ((("kana-voiced-sound"). (""))())
+    ((("kana-semivoiced-sound"). (""))())
+    ((("kana-opening-bracket"). (""))())
+    ((("kana-closing-bracket"). (""))())
+
     (((""). ())(""))
     (((""). ())(""))
     (((""). ())(""))
@@ -325,8 +419,66 @@
     ((("+"). (""))())
     ((("_"). (""))())
     ((("Y"). (""))())
-
     ((("\\"). (""))())
+    ((("yen"). (""))())
+
+    ((("kana-a"). (""))())
+    ((("kana-i"). (""))())
+    ((("kana-u"). (""))())
+    ((("kana-e"). (""))())
+    ((("kana-o"). (""))())
+    ((("kana-ya"). (""))())
+    ((("kana-yu"). (""))())
+    ((("kana-yo"). (""))())
+    ((("kana-wo"). (""))())
+    ((("kana-tsu"). (""))())
+    ((("kana-N"). (""))())
+    ((("kana-A"). (""))())
+    ((("kana-I"). (""))())
+    ((("kana-U"). (""))())
+    ((("kana-E"). (""))())
+    ((("kana-O"). (""))())
+    ((("kana-KA"). (""))())
+    ((("kana-KI"). (""))())
+    ((("kana-KU"). (""))())
+    ((("kana-KE"). (""))())
+    ((("kana-KO"). (""))())
+    ((("kana-SA"). (""))())
+    ((("kana-SHI"). (""))())
+    ((("kana-SU"). (""))())
+    ((("kana-SE"). (""))())
+    ((("kana-SO"). (""))())
+    ((("kana-TA"). (""))())
+    ((("kana-CHI"). (""))())
+    ((("kana-TSU"). (""))())
+    ((("kana-TE"). (""))())
+    ((("kana-TO"). (""))())
+    ((("kana-NA"). (""))())
+    ((("kana-NI"). (""))())
+    ((("kana-NU"). (""))())
+    ((("kana-NE"). (""))())
+    ((("kana-NO"). (""))())
+    ((("kana-HA"). (""))())
+    ((("kana-HI"). (""))())
+    ((("kana-FU"). (""))())
+    ((("kana-HE"). (""))())
+    ((("kana-HO"). (""))())
+    ((("kana-MA"). (""))())
+    ((("kana-MI"). (""))())
+    ((("kana-MU"). (""))())
+    ((("kana-ME"). (""))())
+    ((("kana-MO"). (""))())
+    ((("kana-YA"). (""))())
+    ((("kana-YU"). (""))())
+    ((("kana-YO"). (""))())
+    ((("kana-RA"). (""))())
+    ((("kana-RI"). (""))())
+    ((("kana-RU"). (""))())
+    ((("kana-RE"). (""))())
+    ((("kana-RO"). (""))())
+    ((("kana-WA"). (""))())
+    ((("kana-prolonged-sound"). (""))())
+
     ((("" "@"). ())(""))
     ((("" "@"). ())(""))
     ((("" "@"). ())(""))
@@ -372,6 +524,33 @@
     ((("" "`"). ())(""))
     ((("" "`"). ())(""))
     ((("" "`"). ())(""))
+
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-semivoiced-sound"). ())(""))
+    ((("" "kana-semivoiced-sound"). ())(""))
+    ((("" "kana-semivoiced-sound"). ())(""))
+    ((("" "kana-semivoiced-sound"). ())(""))
+    ((("" "kana-semivoiced-sound"). ())(""))
+
     (((">"). (""))())
     ((("<"). (""))())
     ((("?"). (""))())
@@ -381,6 +560,14 @@
     ((("}"). (""))())
     ((("`"). (""))())
 
+    ((("kana-fullstop"). (""))())
+    ((("kana-comma"). (""))())
+    ((("kana-conjunctive"). (""))())
+    ((("kana-voiced-sound"). (""))())
+    ((("kana-semivoiced-sound"). (""))())
+    ((("kana-opening-bracket"). (""))())
+    ((("kana-closing-bracket"). (""))())
+
     (((""). ())(""))
     (((""). ())(""))
     (((""). ())(""))
@@ -533,8 +720,66 @@
     ((("+"). (""))())
     ((("_"). (""))())
     ((("Y"). (""))())
-
     ((("\\"). (""))())
+    ((("yen"). (""))())
+
+    ((("kana-a"). (""))())
+    ((("kana-i"). (""))())
+    ((("kana-u"). (""))())
+    ((("kana-e"). (""))())
+    ((("kana-o"). (""))())
+    ((("kana-ya"). (""))())
+    ((("kana-yu"). (""))())
+    ((("kana-yo"). (""))())
+    ((("kana-WO"). (""))())
+    ((("kana-tsu"). (""))())
+    ((("kana-N"). (""))())
+    ((("kana-A"). (""))())
+    ((("kana-I"). (""))())
+    ((("kana-U"). (""))())
+    ((("kana-E"). (""))())
+    ((("kana-O"). (""))())
+    ((("kana-KA"). (""))())
+    ((("kana-KI"). (""))())
+    ((("kana-KU"). (""))())
+    ((("kana-KE"). (""))())
+    ((("kana-KO"). (""))())
+    ((("kana-SA"). (""))())
+    ((("kana-SHI"). (""))())
+    ((("kana-SU"). (""))())
+    ((("kana-SE"). (""))())
+    ((("kana-SO"). (""))())
+    ((("kana-TA"). (""))())
+    ((("kana-CHI"). (""))())
+    ((("kana-TSU"). (""))())
+    ((("kana-TE"). (""))())
+    ((("kana-TO"). (""))())
+    ((("kana-NA"). (""))())
+    ((("kana-NI"). (""))())
+    ((("kana-NU"). (""))())
+    ((("kana-NE"). (""))())
+    ((("kana-NO"). (""))())
+    ((("kana-HA"). (""))())
+    ((("kana-HI"). (""))())
+    ((("kana-FU"). (""))())
+    ((("kana-HE"). (""))())
+    ((("kana-HO"). (""))())
+    ((("kana-MA"). (""))())
+    ((("kana-MI"). (""))())
+    ((("kana-MU"). (""))())
+    ((("kana-ME"). (""))())
+    ((("kana-MO"). (""))())
+    ((("kana-YA"). (""))())
+    ((("kana-YU"). (""))())
+    ((("kana-YO"). (""))())
+    ((("kana-RA"). (""))())
+    ((("kana-RI"). (""))())
+    ((("kana-RU"). (""))())
+    ((("kana-RE"). (""))())
+    ((("kana-RO"). (""))())
+    ((("kana-WA"). (""))())
+    ((("kana-prolonged-sound"). (""))())
+
     ((("" "@"). ())(""))
     ((("" "@"). ())(""))
     ((("" "@"). ())(""))
@@ -580,6 +825,33 @@
     ((("" "`"). ())("̎"))
     ((("" "`"). ())("͎"))
     ((("" "`"). ())("Ύ"))
+
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())(""))
+    ((("" "kana-voiced-sound"). ())("Î"))
+    ((("" "kana-voiced-sound"). ())("Ď"))
+    ((("" "kana-voiced-sound"). ())("ʎ"))
+    ((("" "kana-voiced-sound"). ())("ˎ"))
+    ((("" "kana-voiced-sound"). ())("̎"))
+    ((("" "kana-voiced-sound"). ())("͎"))
+    ((("" "kana-voiced-sound"). ())("Ύ"))
+    ((("" "kana-semivoiced-sound"). ())("ʎ"))
+    ((("" "kana-semivoiced-sound"). ())("ˎ"))
+    ((("" "kana-semivoiced-sound"). ())("̎"))
+    ((("" "kana-semivoiced-sound"). ())("͎"))
+    ((("" "kana-semivoiced-sound"). ())("Ύ"))
+ 
     (((">"). (""))())
     ((("<"). (""))())
     ((("?"). (""))())
@@ -589,6 +861,14 @@
     ((("}"). (""))())
     ((("`"). (""))())
 
+    ((("kana-fullstop"). (""))())
+    ((("kana-comma"). (""))())
+    ((("kana-conjunctive"). (""))())
+    ((("kana-voiced-sound"). (""))())
+    ((("kana-semivoiced-sound"). (""))())
+    ((("kana-opening-bracket"). (""))())
+    ((("kana-closing-bracket"). (""))())
+ 
     (((""). ())(""))
     (((""). ())(""))
     (((""). ())(""))
